@@ -19,7 +19,7 @@ PApp::Application - a class representing a single mountable application
 
 =head1 DESCRIPTION
 
-What?
+This class is the base class for all mountable PApp applications.
 
 =over 4
 
@@ -39,7 +39,7 @@ use Convert::Scalar ();
 use utf8;
 no bytes;
 
-$VERSION = 0.95;
+$VERSION = 1.1;
 
 =item $papp = new PApp::Application args...
 
@@ -53,7 +53,7 @@ sub new {
 
 =item $ppkg->preprocess
 
-Parse the package (includign all subpackages) and store the configuration
+Parse the package (including all subpackages) and store the configuration
 and code data in the PApp Package Cache(tm) for use by load_config and
 load_code.
 
@@ -242,18 +242,19 @@ sub files($;$) {
 
 "Run" the application, i.e. find the current package & module and execute it.
 
-=item $papp->callback_exception
+=item $papp->uncaught_exception ($exception, $callback)
 
-This method is called when a surl callback die's. The cause is still in
-C<$@>. This method is free to call C<abort_to> or other functions. If it
-returns, the exception will be ignored.
+This method is called when a surl callback dies ($callback true) or
+another exception is caught by papp ($callback false).This method is free
+to call C<abort_to> or other functions. If it returns, the exception will
+be ignored.
 
 The default implementation just rethrows.
 
 =cut
 
-sub callback_exception {
-   die;
+sub uncaught_exception {
+   PApp::handle_error ($_[0]);
 }
 
 =item $papp->new_package(same arguments as PApp::Package->new)
@@ -437,7 +438,7 @@ sub load_code {
    });
 
    for my $type (qw(init childinit childexit)) {
-      my $cb = join ";", PApp::Util::uniq delete $self->{cb_src}{$type};
+      my $cb = join ";", PApp::Util::uniq @{ delete $self->{cb_src}{$type} };
       $self->{cb}{$type} = eval "use utf8; no bytes; sub {\n$cb\n}";
       fancydie "error while compiling application callback", $@,
                info => [name => $self->{name}],
@@ -544,14 +545,16 @@ sub run {
    $papp->{obj}->show;
 }
 
-=item $papp->callback_exception
+=over 4
 
-The Agni-specific version of this method calls the C<callback_exception>
+=item $papp->uncaught_exception
+
+The Agni-specific version of this method calls the C<uncaught_exception>
 method of the mounted application.
 
 =cut
 
-sub callback_exception {
+sub uncaught_exception {
    package PApp;
 
    local $papp    = shift;
@@ -561,7 +564,7 @@ sub callback_exception {
    local $PApp::SQL::Database = $PApp::Config::Database;
    local $PApp::SQL::DBH      = $PApp::Config::DBH;
 
-   $papp->{obj}->callback_exception;
+   $papp->{obj}->uncaught_exception ($_[0], $_[1]);
 }
 
 1;
@@ -572,8 +575,8 @@ L<PApp>.
 
 =head1 AUTHOR
 
- Marc Lehmann <pcg@goof.com>
- http://www.goof.com/pcg/marc/
+ Marc Lehmann <schmorp@schmorp.de>
+ http://home.schmorp.de/
 
 =cut
 
