@@ -37,7 +37,7 @@ use PApp::SQL;
 
 use base Exporter;
 
-$VERSION = 0.95;
+$VERSION = 1.1;
 @EXPORT = qw(locked);
 
 =item locked BLOCK name, [timeout, [holdtime]]
@@ -171,8 +171,8 @@ L<PApp>.
 
 =head1 AUTHOR
 
- Marc Lehmann <pcg@goof.com>
- http://www.goof.com/pcg/marc/
+ Marc Lehmann <schmorp@schmorp.de>
+ http://home.schmorp.de/
 
 =cut
 
