@@ -32,13 +32,13 @@ package PApp::MimeType;
 
 use base Exporter;
 
-$VERSION = 0.95;
+$VERSION = 1.1;
 @EXPORT_OK = qw(by_extension by_filename by_mimetype clear_mimedb load_mimedb);
 
 my %by_extension;
 my %by_mimetype;
 
-=head2 LOOKUP FUNCTIONS
+=head2 Lookup Functions
 
 These functions look up (existing) mimetype objects and return it. Watch
 out, they are not constructors, so either import them to your namespace or
@@ -96,7 +96,7 @@ sub by_mimetype($) {
 
 =back
 
-=head2 METHODS
+=head2 Methods
 
 C<PApp::MimeType> objects are immutable, and support a number of methods.
 
@@ -141,7 +141,7 @@ sub extensions($) {
 
 =back
 
-=head2 DATABASE FUNCTIONS
+=head2 Database Functions
 
 The mime database is initialized on demand form a default file. If you
 want to overwrite or augment it, use the following functions:
@@ -223,8 +223,8 @@ L<PApp>.
 
 =head1 AUTHOR
 
- Marc Lehmann <pcg@goof.com>
- http://www.goof.com/pcg/marc/
+ Marc Lehmann <schmorp@schmorp.de>
+ http://home.schmorp.de/
 
 =cut
 
